String Encoding - kombu.utils.encoding — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# String Encoding - kombu.utils.encoding

`kombu.utils.encoding.` `default_encoding`()

`kombu.utils.encoding.` `safe_repr`(o, errors='replace')

`kombu.utils.encoding.` `safe_str`(s, errors='replace')

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »